package Task::PYX;

# Pragmas.
use strict;
use warnings;

# Version.
our $VERSION = 0.04;

1;

__END__

=pod

=encoding utf8

=head1 NAME

Task::PYX - Install the PYX modules.

=head1 SYNOPSIS

 cpanm Task::PYX

=head1 SEE ALSO

L<PYX>,
L<PYX::GraphViz>,
L<PYX::Hist>,
L<PYX::Parser>,
L<PYX::Stack>,
L<PYX::Utils>.

=head1 REPOSITORY

L<https://github.com/tupinek/Task-PYX>

=head1 AUTHOR

Michal Špaček L<mailto:skim@cpan.org>

L<http://skim.cz>

=head1 LICENSE AND COPYRIGHT

 © 2015 Michal Špaček
 Artistic License
 BSD 2-Clause License

=head1 VERSION

0.04

=cut
